# ocsp-responder-server
OCSP responder server

Run an OCSP Responder json-rpc server, mirrors openssl_ocsp_responder.OCSPResponder functionalities (start_responder, stop_responder, is_alive,...)

`python -m ocsp_responder_server.OCSP_server.py <ocsp responder configuration>`